==> haskell-http-api-data-0.5.1-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.5.1
visibility:           public
id:                   http-api-data-0.5.1-4SAtcM8zrdv8pg3M4JRGjK
key:                  http-api-data-0.5.1-4SAtcM8zrdv8pg3M4JRGjK
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  323f5692cf82d01c54c356db198ef176
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.5.1-4SAtcM8zrdv8pg3M4JRGjK
depends:
    attoparsec-0.14.4-9F9tnN8VDhqE7eiteCM5HG
    attoparsec-iso8601-1.1.0.0-OsTfZs7F543wzUjTa2Wxc base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    containers-0.6.5.1 cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    hashable-1.4.4.0-JPPoH0HitSIaCdulNsJk5
    http-types-0.12.4-7cXCeYy1EdF4iPzsHuuw3e
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    time-compat-1.9.6.1-9wa5HM0UjaJFKO8e02Yuwm transformers-0.5.6.2
    unordered-containers-0.2.20-E4Tm9IvXwjlGK4H2DBnoSH
    uuid-types-1.0.5.1-LfdQaQtimrF27WwXkBX9iU

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.5.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.5.1
visibility:           public
id:                   http-api-data-0.5.1-Cq6gvErzLtRIWNTMSz0oQ5
key:                  http-api-data-0.5.1-Cq6gvErzLtRIWNTMSz0oQ5
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  61af2b6cb919ab6ebe4e1476600215b2
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-api-data-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.5.1-Cq6gvErzLtRIWNTMSz0oQ5
depends:
    attoparsec-0.14.4-7XtEyfF24RF27dz6MIAdRK
    attoparsec-iso8601-1.1.0.0-In2SCTgPlGJ7J7p2GtqCSW base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    containers-0.6.5.1 cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal
    http-types-0.12.4-7L1Xgr7iL2Z2aE7E1VRA2h
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    time-compat-1.9.6.1-9TpUeYWiBEKJvzjfvAo5zr transformers-0.5.6.2
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q
    uuid-types-1.0.5.1-5XVSegQhTJxLWMhfB0jOyk

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
